package com.steerinfo.dil.controller;

import com.steerinfo.dil.mapper.StatisticalReportMapper;
import com.steerinfo.dil.service.impl.StatisticalReportImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import oracle.jdbc.proxy.annotation.Post;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ author    :TXF
 * @ time      :2021/12/14 18:05
 */

@RestController
@RequestMapping("/${api.version}/statisticalReport")
public class StatisticalReportController extends BaseRESTfulController {

    @Autowired
    StatisticalReportImpl statisticalReportService;

    @Autowired
    ColumnDataUtil columnDataUtil;



    private final SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM-dd");

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    @ApiOperation(value="查询辅料燃料统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(220)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getRLFLReport")
    public RESTfulResult getRLFLReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String startTime,
                                               String endTime,
                                               Integer orderType,
                                               String con
    ){
        mapValue.put("orderTypee", orderType);
        if (con!=null && !"null".equals(con) && !"".equals(con)){
            mapValue.put("con",con);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getRLFLReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,report);
        return success(pageList);
    }


    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllSaleReport")
    public RESTfulResult getAllSaleReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String carrierSsoId,
                                          Integer orderType,
                                          Integer shipperId,
                                          String receiveName,
                                          String materialName,
                                          String wareHouse
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            mapValue.put("receivName","%" + receiveName + "%");
        }
        if (materialName != null && !"".equals(materialName) && !"null".equals(materialName)) {
            mapValue.put("remark","%" + materialName + "%");
        }
        if (wareHouse != null && !"".equals(wareHouse) && !"null".equals(wareHouse)) {
            mapValue.put("wareHouse","%" + wareHouse + "%");
        }
        mapValue.put("orderTypee",orderType);
        mapValue.put("shipperId",shipperId);
        if(orderType==1 && mapValue.get("orderField")==null){
            //如果没有使用排序且查询的表格类型为销售钢材内部专用表格，默认规格排序
            mapValue.put("orderField","materialCode");
            mapValue.put("orderType","desc");
        }
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getAllSaleReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData5(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllSaleReportNew")
    public RESTfulResult getAllSaleReportNew(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                          Integer orderType,
                                          Integer shipperId,
                                          String receiveName,
                                          String materialName,
                                          String wareHouse
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            mapValue.put("receivName","%" + receiveName + "%");
        }
        if (materialName != null && !"".equals(materialName) && !"null".equals(materialName)) {
            mapValue.put("remark","%" + materialName + "%");
        }
        if (wareHouse != null && !"".equals(wareHouse) && !"null".equals(wareHouse)) {
            mapValue.put("wareHouse","%" + wareHouse + "%");
        }
        mapValue.put("orderTypee",orderType);
        mapValue.put("shipperId",shipperId);
        if(orderType==1 && mapValue.get("orderField")==null){
            //如果没有使用排序且查询的表格类型为销售钢材内部专用表格，默认规格排序
            mapValue.put("orderField","materialCode");
            mapValue.put("orderType","desc");
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getAllSaleReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData5(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询销售统计报表筛选过后的总净重")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllSaleReportTotal")
    public RESTfulResult getAllSaleReportTotal(@RequestBody(required=false) Map<String,Object> mapValue,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId
    ){
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        List<Map<String, Object>> allReport =  statisticalReportService.getAllSaleReportNum(mapValue);
        //获取销售统计报表筛选过后的总净重
        BigDecimal AllResultNetWeight = new BigDecimal(0);
        for (Map<String, Object> stringObjectMap : allReport) {
            if(stringObjectMap.get("resultNetWeight")!=null) {
                AllResultNetWeight = AllResultNetWeight.add(new BigDecimal(stringObjectMap.get("resultNetWeight").toString()));
            }
        }
        return success(AllResultNetWeight);
    }

    @ApiOperation(value="查询零星物资进厂统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(424)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSporadicSuppliesReport1")
    public RESTfulResult getSporadicSuppliesReport1(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                          String userId, String userIds, String con, Integer orderType
    ){
        if(carrierSsoId != null) {
            if (!"null".equals(carrierSsoId)) {
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (orderType!=null){
            mapValue.put("orderType",orderType);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        if (con!=null&&!"null".equals(con)){
            mapValue.put("con","%"+con+"%");
        }
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSporadicSuppliesReport1(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询零星物资出厂统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(425)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSporadicSuppliesReport2")
    public RESTfulResult getSporadicSuppliesReport2(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   Integer apiId,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   String startTime,
                                                   String endTime,
                                                   String carrierSsoId,
                                                    String userId,
                                                    String userIds,
                                                    String con,
                                                    Integer orderType
    ){
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if (con!=null&&!"null".equals(con)){
            mapValue.put("con","%"+con+"%");
        }
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (orderType!=null){
            mapValue.put("orderType",orderType);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSporadicSuppliesReport2(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询采购内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurInwardReport")
    public RESTfulResult getPurInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String startTime,
                                                    String endTime
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getPurInwardReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询零星内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLXInwardReport")
    public RESTfulResult getLXInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            String startTime,
                                            String endTime,
                                           String con
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(con != null && !"null".equals(con)){
            mapValue.put("con","%" + con + "%");
        }
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLXInwardReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardReport")
    public RESTfulResult getInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            String startTime,
                                            String endTime
    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "486", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleOrderList")
    public RESTfulResult getSaleOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String startTime,
                                         String endTime,
                                         String orgCode,
                                         String isPage,
                                          String index
    ){
         if (orgCode!=null&&!"null".equals(orgCode)){
             mapValue.put("orgCode",orgCode);
         }
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if("yes".equals(isPage)){
            return success(statisticalReportService.getSaleOrderList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleOrderList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation(value="查询该组织机构下的采购统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "486", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurchaseOrderList")
    public RESTfulResult getPurchaseOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String orgCode,
                                              String isPage,
                                              String index
    ){

        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return success(statisticalReportService.getPurchaseOrderList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getPurchaseOrderList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的采购内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "s", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurchaseInwardList")
    public RESTfulResult getInwardList(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String startTime,
                                              String endTime,
                                              String orgCode,
                                                String isPage,
                                             String index
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getPurchaseInwardList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getPurchaseInwardList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的厂外进厂内转")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "s", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOutFactoryInwardList")
    public RESTfulResult getOutFactoryInwardList(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String orgCode,
                                       String isPage,
                                       String index
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getOutFactoryInwardList(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getOutFactoryInwardList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation(value="查询该组织机构下的内转统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "s", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardInFactory")
    public RESTfulResult getInwardInFactory(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String orgCode,
                                       String isPage,
                                       String index
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getInwardInFactory(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardInFactory(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData4(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation(value="查询拼装车统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "477", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardReportForAssemble")
    public RESTfulResult getInwardReportForAssemble(@RequestBody(required=false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String startTime,
                                         String endTime, BigDecimal orderType, String index, String isPage,String orgCode
    ){
        if (index!=null&&!"null".equals(index)){
            mapValue.put("index",index);
        }
        if (orgCode!=null&&!"null".equals(orgCode)){
            mapValue.put("orgCode",orgCode);
        }
        if (orderType!=null&&!"null".equals(orderType)){
            mapValue.put("orderTypee",orderType);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if ("yes".equals(isPage)){
            return  success(statisticalReportService.getInwardReportForAssemble(mapValue));
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardReportForAssemble(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }
    @ApiOperation(value="装机展示明细")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId", value = "477", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLoaderForResultDetail")
    public RESTfulResult getLoaderForResultDetail(@RequestBody(required=false) Map<String,Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String startTime,
                                                    String endTime,
                                                    String con,
                                                    String isPage
    ){
        if (con != null && !"undefined".equals(con)) {
            mapValue.put("con",con);
        }

        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if(isPage != null && !"".equals(isPage)){
            List<Map<String, Object>> report = statisticalReportService.getLoaderForResultDetail(mapValue);
            return success(report);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLoaderForResultDetail(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation("对内转车辆装货点进行统计")
    @PostMapping("/getLoading")
    public RESTfulResult getLoading(@RequestBody(required=false) Map<String,Object> mapValue,
                                    Integer apiId,
                                    Integer pageNum,
                                    Integer pageSize,
                                    String startTime,
                                    String endTime){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLoading(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation("装载机所装车辆重量统计报表")
    @PostMapping("/getLoaderResult")
    public RESTfulResult getLoaderResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                    Integer apiId,//apiId:463
                                    Integer pageNum,
                                    Integer pageSize,
                                    String startTime,
                                    String endTime){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getLoaderResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }

    @ApiOperation("对内转车辆装卸货点进行统计")
    @PostMapping("/getUnLoading")
    public RESTfulResult getUnLoading(@RequestBody(required=false) Map<String,Object> mapValue,
                                    Integer apiId,
                                    Integer pageNum,
                                    Integer pageSize,
                                    String startTime,
                                    String endTime){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if(mapValue.get("isExcel")==null){
            PageHelper.startPage(pageNum, pageSize);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getUnLoading(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);

        return success(pageList);
    }

    //保卫部随机抽查车牌号查看所有信息
    @ApiOperation("保卫部随机抽查车牌号查看所有信息")
    @PostMapping("/getCapacityByDefend")
    public RESTfulResult getCapacityByDefend(@RequestBody(required = false) Map<String,Object> map,
                                             Integer apiId,
                                             Integer pageNum,
                                             Integer pageSize,
                                             String startTime,
                                             String endTime,
                                             String con,
                                             String yes){
        if (con != null && !"null".equals(con)) {
            map.put("con",con);
        }
        DataChange.queryDataByDateTime(startTime ,endTime, map, sdfDateTime);//根据时间段查询数据
        if(yes != null && !"null".equals(yes)){
            return success(statisticalReportService.getCapacityByDefend(map));
        }
        PageHelper.startPage(pageNum, pageSize);
        List<Map<String, Object>> report = statisticalReportService.getCapacityByDefend(map);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null, report);
        return success(pageList);
    }


    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleSteelReport")
    public RESTfulResult getSaleSteelReport(@RequestBody(required=false) Map<String,Object> map,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                          String receiveName,
                                          String materialName,
                                          String specification,
                                          String remark,
                                          String capacityNo,
                                          String carrierName,
                                          String consigneeName,
                                          String saler,
                                          String easPrimaryId
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            //如果业务员登录进来,就去查询业务员所关联的片区
            List<String> saleAreaRemark = statisticalReportService.getSaleAreaRemark(saler);
            if(saleAreaRemark.size() > 0) {
                map.put("saleAreaRemark",saleAreaRemark);
            }
            map.put("salers",saler);
        }
        if (easPrimaryId != null && !"".equals(easPrimaryId) && !"null".equals(easPrimaryId)) {
            map.put("easPrimaryId",easPrimaryId);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleSteelReport(map);
        for (Map<String, Object> stringObjectMap : report) {
            String shippingAddressIds = (String) stringObjectMap.get("shippingAddressIds");
            String capacityNumbers= (String) stringObjectMap.get("capacityNumbers");
            //确认是否有多个收货单位
            if (shippingAddressIds !=null && !("".equals(shippingAddressIds))){
                String[] split = shippingAddressIds.split(",");
                String address="";
                int i=0;
                for (String s : split) {
                    i++;
                    String getaddress = statisticalReportService.getaddress(DataChange.dataToBigDecimal(s));
                    if (i==1){
                        address+="旧地址:"+getaddress+",";
                    }else if (i==2){
                        address+="新地址:"+getaddress;
                    }
                }
                stringObjectMap.put("addressPlace",address);
            }
            //确认是否有多个车牌号
            if (capacityNumbers!=null &&!("".equals(capacityNumbers))){
                String[] split = capacityNumbers.split(",");
                String capacityNumber="";
                int flag=0;
                for (String s : split) {
                    flag++;
                    String s1 = statisticalReportService.getcapacityNumber(DataChange.dataToBigDecimal(s));
                    if (flag==1){
                        capacityNumber+="旧车号:"+s1+",";
                    }else if (flag==2){
                        capacityNumber+="新车号:"+s1;
                        break;
                    }
                }
                stringObjectMap.put("capacityNo",capacityNumber);
            }
            /*try{
                BigDecimal orderId = (BigDecimal) stringObjectMap.get("orderId");
                if (orderId !=null){
                    String status = statisticalReportService.getStatus(orderId);
                    if (!(" ".equals(status))){
                        stringObjectMap.put("orderStatus",status);
                    }
                }
            }catch (Exception e){
                e.printStackTrace();
            }*/
        }
        return success(report);
    }

    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleSteelSpellingReport")
    public RESTfulResult getSaleSteelSpellingReport(@RequestBody(required=false) Map<String,Object> map
    ){
        String startTime = (String)map.get("startTime");
        String endTime = (String) map.get("endTime");
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleSteelSpellingReport(map);
        //初始化Map的值
        Map<String,Object> map1=new HashMap<>();
        map1.put("pinZhuang",null);
        map1.put("chongQinSpellingData",0);
        map1.put("chengDuSpellingData",0);
        map1.put("gongChengSpellingData",0);
        map1.put("chaungDongSpellingData",0);
        map1.put("AllSpellingData",0);
        Map<String,Object> map2=new HashMap<>();
        map2.put("pinZhuang",null);
        map2.put("chongQinSpellingData",0);
        map2.put("chengDuSpellingData",0);
        map2.put("gongChengSpellingData",0);
        map2.put("chaungDongSpellingData",0);
        map2.put("AllSpellingData",0);
        Map<String,Object> map3=new HashMap<>();
        map3.put("pinZhuang",null);
        map3.put("chongQinSpellingData",0);
        map3.put("chengDuSpellingData",0);
        map3.put("gongChengSpellingData",0);
        map3.put("chaungDongSpellingData",0);
        map3.put("AllSpellingData",0);
        Map<String,Object> map4=new HashMap<>();
        map4.put("pinZhuang",null);
        map4.put("chongQinSpellingData",0);
        map4.put("chengDuSpellingData",0);
        map4.put("gongChengSpellingData",0);
        map4.put("chaungDongSpellingData",0);
        map4.put("AllSpellingData",0);
        Map<String,Object> map5=new HashMap<>();
        map5.put("pinZhuang",null);
        map5.put("chongQinSpellingData",0);
        map5.put("chengDuSpellingData",0);
        map5.put("gongChengSpellingData",0);
        map5.put("chaungDongSpellingData",0);
        map5.put("AllSpellingData",0);
        Map<String,Object> map6=new HashMap<>();
        map6.put("pinZhuang",null);
        map6.put("chongQinSpellingData",0);
        map6.put("chengDuSpellingData",0);
        map6.put("gongChengSpellingData",0);
        map6.put("chaungDongSpellingData",0);
        map6.put("AllSpellingData",0);
        Map<String,Object> map7=new HashMap<>();
        map7.put("pinZhuang",null);
        map7.put("chongQinSpellingData",0);
        map7.put("chengDuSpellingData",0);
        map7.put("gongChengSpellingData",0);
        map7.put("chaungDongSpellingData",0);
        map7.put("AllSpellingData",0);
        //35个数据
        List<Map<String,Object>> spellingData=new LinkedList<>();
        //初始化list集合的值
        spellingData.add(map1);
        spellingData.add(map2);
        spellingData.add(map3);
        spellingData.add(map4);
        spellingData.add(map5);
        spellingData.add(map6);
        spellingData.add(map7);
        spellingData.get(0).put("pinZhuang","一拼");
        spellingData.get(1).put("pinZhuang","二拼");
        spellingData.get(2).put("pinZhuang","三拼");
        spellingData.get(3).put("pinZhuang","四拼");
        spellingData.get(4).put("pinZhuang","五拼");
        spellingData.get(5).put("pinZhuang","六拼");
        spellingData.get(6).put("pinZhuang","合计");
        for (Map<String, Object> stringObjectMap : report) {
            int flag=0;
            String areaName = (String) stringObjectMap.get("areaName");
            //销售订单号
            if (areaName==null){
                continue;
            }
            BigDecimal spellingNum =  DataChange.dataToBigDecimal(stringObjectMap.get("spellingNum"));
            if (spellingNum.compareTo(BigDecimal.valueOf(1))==0){
                if (areaName.equals("钢材重庆组")){
                    Integer oneSpellingData = (Integer) spellingData.get(0).get("chongQinSpellingData");
                    if (spellingData.get(0).get("chongQinSpellingData")!=null){
                        spellingData.get(0).put("chongQinSpellingData",oneSpellingData+1);
                    }else {
                        spellingData.get(0).put("chongQinSpellingData",1);
                    }
                }else if (areaName.equals("钢材成都组")){
                    Integer oneSpellingData1 = (Integer) spellingData.get(0).get("chengDuSpellingData");
                    if (spellingData.get(0).get("chengDuSpellingData")!=null){
                        spellingData.get(0).put("chengDuSpellingData",oneSpellingData1+1);
                    }else {
                        spellingData.get(0).put("chengDuSpellingData",1);
                    }
                }else if (areaName.equals("钢材工程组")){
                    Integer oneSpellingData2 = (Integer) spellingData.get(0).get("gongChengSpellingData");
                    if (spellingData.get(0).get("gongChengSpellingData")!=null){
                        spellingData.get(0).put("gongChengSpellingData",oneSpellingData2+1);
                    }else {
                        spellingData.get(0).put("gongChengSpellingData",1);
                    }
                }else if (areaName.equals("钢材南充组")||areaName.equals("钢材达州组")||areaName.equals("钢材万州组")){
                    Integer oneSpellingData3 = (Integer) spellingData.get(0).get("chaungDongSpellingData");
                    if (oneSpellingData3!=null){
                        spellingData.get(0).put("chaungDongSpellingData",oneSpellingData3+1);
                    }else {
                        spellingData.get(0).put("chaungDongSpellingData",1);
                    }
                }
                Integer oneSpellingData4 = (Integer) spellingData.get(0).get("AllSpellingData");
                if (oneSpellingData4!=null){
                    spellingData.get(0).put("AllSpellingData",oneSpellingData4+1);
                }else {
                    spellingData.get(0).put("AllSpellingData",1);
                }
            }else if (spellingNum.compareTo(BigDecimal.valueOf(2))==0){
                if (areaName.equals("钢材重庆组")){
                    Integer oneSpellingData = (Integer) spellingData.get(1).get("chongQinSpellingData");
                    if (oneSpellingData!=null){
                        spellingData.get(1).put("chongQinSpellingData",oneSpellingData+1);
                    }else {
                        spellingData.get(1).put("chongQinSpellingData",1);
                    }
                }else if (areaName.equals("钢材成都组")){
                    Integer oneSpellingData1 = (Integer) spellingData.get(1).get("chengDuSpellingData");
                    if (oneSpellingData1!=null){
                        spellingData.get(1).put("chengDuSpellingData",oneSpellingData1+1);
                    }else {
                        spellingData.get(1).put("chengDuSpellingData",1);
                    }
                }else if (areaName.equals("钢材工程组")){
                    Integer oneSpellingData2 = (Integer) spellingData.get(1).get("gongChengSpellingData");
                    if (oneSpellingData2!=null){
                        spellingData.get(1).put("gongChengSpellingData",oneSpellingData2+1);
                    }else {
                        spellingData.get(1).put("gongChengSpellingData",1);
                    }
                }else if (areaName.equals("钢材南充组")||areaName.equals("钢材达州组")||areaName.equals("钢材万州组")){
                    Integer oneSpellingData3 = (Integer) spellingData.get(1).get("chaungDongSpellingData");
                    if (oneSpellingData3!=null){
                        spellingData.get(1).put("chaungDongSpellingData",oneSpellingData3+1);
                    }else {
                        spellingData.get(1).put("chaungDongSpellingData",1);
                    }
                }
                Integer oneSpellingData4 = (Integer) spellingData.get(1).get("AllSpellingData");
                if (oneSpellingData4!=null){
                    spellingData.get(1).put("AllSpellingData",oneSpellingData4+1);
                }else {
                    spellingData.get(1).put("AllSpellingData",1);
                }
            }else if (spellingNum.compareTo(BigDecimal.valueOf(3))==0){
                if (areaName.equals("钢材重庆组")){
                    Integer oneSpellingData = (Integer) spellingData.get(2).get("chongQinSpellingData");
                    if (oneSpellingData!=null){
                        spellingData.get(2).put("chongQinSpellingData",oneSpellingData+1);
                    }else {
                        spellingData.get(2).put("chongQinSpellingData",1);
                    }
                }else if (areaName.equals("钢材成都组")){
                    Integer oneSpellingData1 = (Integer) spellingData.get(2).get("chengDuSpellingData");
                    if (oneSpellingData1!=null){
                        spellingData.get(2).put("chengDuSpellingData",oneSpellingData1+1);
                    }else {
                        spellingData.get(2).put("chengDuSpellingData",1);
                    }
                }else if (areaName.equals("钢材工程组")){
                    Integer oneSpellingData2 = (Integer) spellingData.get(2).get("gongChengSpellingData");
                    if (oneSpellingData2!=null){
                        spellingData.get(2).put("gongChengSpellingData",oneSpellingData2+1);
                    }else {
                        spellingData.get(2).put("gongChengSpellingData",1);
                    }
                }else if (areaName.equals("钢材南充组")||areaName.equals("钢材达州组")||areaName.equals("钢材万州组")){
                    Integer oneSpellingData3 = (Integer) spellingData.get(2).get("chaungDongSpellingData");
                    if (oneSpellingData3!=null){
                        spellingData.get(2).put("chaungDongSpellingData",oneSpellingData3+1);
                    }else {
                        spellingData.get(2).put("chaungDongSpellingData",1);
                    }
                }
                Integer oneSpellingData4 = (Integer) spellingData.get(2).get("AllSpellingData");
                if (oneSpellingData4!=null){
                    spellingData.get(2).put("AllSpellingData",oneSpellingData4+1);
                }else {
                    spellingData.get(2).put("AllSpellingData",1);
                }
            }else if (spellingNum.compareTo(BigDecimal.valueOf(4))==0){
                if (areaName.equals("钢材重庆组")){
                    Integer oneSpellingData = (Integer) spellingData.get(3).get("chongQinSpellingData");
                    if (oneSpellingData!=null){
                        spellingData.get(3).put("chongQinSpellingData",oneSpellingData+1);
                    }else {
                        spellingData.get(3).put("chongQinSpellingData",1);
                    }
                }else if (areaName.equals("钢材成都组")){
                    Integer oneSpellingData1 = (Integer) spellingData.get(3).get("chengDuSpellingData");
                    if (oneSpellingData1!=null){
                        spellingData.get(3).put("chengDuSpellingData",oneSpellingData1+1);
                    }else {
                        spellingData.get(3).put("chengDuSpellingData",1);
                    }
                }else if (areaName.equals("钢材工程组")){
                    Integer oneSpellingData2 = (Integer) spellingData.get(3).get("gongChengSpellingData");
                    if (oneSpellingData2!=null){
                        spellingData.get(3).put("gongChengSpellingData",oneSpellingData2+1);
                    }else {
                        spellingData.get(3).put("gongChengSpellingData",1);
                    }
                }else if (areaName.equals("钢材南充组")||areaName.equals("钢材达州组")||areaName.equals("钢材万州组")){
                    Integer oneSpellingData3 = (Integer) spellingData.get(3).get("chaungDongSpellingData");
                    if (oneSpellingData3!=null){
                        spellingData.get(3).put("chaungDongSpellingData",oneSpellingData3+1);
                    }else {
                        spellingData.get(3).put("chaungDongSpellingData",1);
                    }
                }
                Integer oneSpellingData4 = (Integer) spellingData.get(3).get("AllSpellingData");
                if (oneSpellingData4!=null){
                    spellingData.get(3).put("AllSpellingData",oneSpellingData4+1);
                }else {
                    spellingData.get(3).put("AllSpellingData",1);
                }
            }else if (spellingNum.compareTo(BigDecimal.valueOf(5))==0){
                if (areaName.equals("钢材重庆组")){
                    Integer oneSpellingData = (Integer) spellingData.get(4).get("chongQinSpellingData");
                    if (oneSpellingData!=null){
                        spellingData.get(4).put("chongQinSpellingData",oneSpellingData+1);
                    }else {
                        spellingData.get(4).put("chongQinSpellingData",1);
                    }
                }else if (areaName.equals("钢材成都组")){
                    Integer oneSpellingData1 = (Integer) spellingData.get(4).get("chengDuSpellingData");
                    if (oneSpellingData1!=null){
                        spellingData.get(4).put("chengDuSpellingData",oneSpellingData1+1);
                    }else {
                        spellingData.get(4).put("chengDuSpellingData",1);
                    }
                }else if (areaName.equals("钢材工程组")){
                    Integer oneSpellingData2 = (Integer) spellingData.get(4).get("gongChengSpellingData");
                    if (oneSpellingData2!=null){
                        spellingData.get(4).put("gongChengSpellingData",oneSpellingData2+1);
                    }else {
                        spellingData.get(4).put("gongChengSpellingData",1);
                    }
                }else if (areaName.equals("钢材南充组")||areaName.equals("钢材达州组")||areaName.equals("钢材万州组")){
                    Integer oneSpellingData3 = (Integer) spellingData.get(4).get("chaungDongSpellingData");
                    if (oneSpellingData3!=null){
                        spellingData.get(4).put("chaungDongSpellingData",oneSpellingData3+1);
                    }else {
                        spellingData.get(4).put("chaungDongSpellingData",1);
                    }
                }
                Integer oneSpellingData4 = (Integer) spellingData.get(4).get("AllSpellingData");
                if (oneSpellingData4!=null){
                    spellingData.get(4).put("AllSpellingData",oneSpellingData4+1);
                }else {
                    spellingData.get(4).put("AllSpellingData",1);
                }
            }else if (spellingNum.compareTo(BigDecimal.valueOf(6))==0){
                if (areaName.equals("钢材重庆组")){
                    Integer oneSpellingData = (Integer) spellingData.get(5).get("chongQinSpellingData");
                    if (oneSpellingData!=null){
                        spellingData.get(5).put("chongQinSpellingData",oneSpellingData+1);
                    }else {
                        spellingData.get(5).put("chongQinSpellingData",1);
                    }
                }else if (areaName.equals("钢材成都组")){
                    Integer oneSpellingData1 = (Integer) spellingData.get(5).get("chengDuSpellingData");
                    if (oneSpellingData1!=null){
                        spellingData.get(5).put("chengDuSpellingData",oneSpellingData1+1);
                    }else {
                        spellingData.get(5).put("chengDuSpellingData",1);
                    }
                }else if (areaName.equals("钢材工程组")){
                    Integer oneSpellingData2 = (Integer) spellingData.get(5).get("gongChengSpellingData");
                    if (oneSpellingData2!=null){
                        spellingData.get(5).put("gongChengSpellingData",oneSpellingData2+1);
                    }else {
                        spellingData.get(5).put("gongChengSpellingData",1);
                    }
                }else if (areaName.equals("钢材南充组")||areaName.equals("钢材达州组")||areaName.equals("钢材万州组")){
                    Integer oneSpellingData3 = (Integer) spellingData.get(5).get("chaungDongSpellingData");
                    if (oneSpellingData3!=null){
                        spellingData.get(5).put("chaungDongSpellingData",oneSpellingData3+1);
                    }else {
                        spellingData.get(5).put("chaungDongSpellingData",1);
                    }
                }
                Integer oneSpellingData4 = (Integer) spellingData.get(5).get("AllSpellingData");
                if (oneSpellingData4!=null){
                    spellingData.get(5).put("AllSpellingData",oneSpellingData4+1);
                }else {
                    spellingData.get(5).put("AllSpellingData",1);
                }
            }
        }
        //每一列的合计
        int oneData=0;
        int twoData=0;
        int threeData=0;
        int fourData=0;
        int fiveData=0;
        for (int i = 0; i < spellingData.size(); i++) {
            oneData+=(int) spellingData.get(i).get("chongQinSpellingData");
            twoData+=(int) spellingData.get(i).get("chengDuSpellingData");
            threeData+=(int) spellingData.get(i).get("gongChengSpellingData");
            fourData+=(int) spellingData.get(i).get("chaungDongSpellingData");
            fiveData+=(int) spellingData.get(i).get("AllSpellingData");
        }
        spellingData.get(6).put("chongQinSpellingData",oneData);
        spellingData.get(6).put("chengDuSpellingData",twoData);
        spellingData.get(6).put("gongChengSpellingData",threeData);
        spellingData.get(6).put("chaungDongSpellingData",fourData);
        spellingData.get(6).put("AllSpellingData",fiveData);
        return success(spellingData);
    }

    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleSteelReportNew")
    public RESTfulResult getSaleSteelReportNew(@RequestBody(required=false) Map<String,Object> map,
                                            String startTime,
                                            String endTime,
                                            String carrierSsoId,
                                            String receiveName,
                                            String materialName,
                                            String specification,
                                            String remark,
                                            String capacityNo,
                                            String carrierName,
                                            String consigneeName,
                                            String saler,
                                            String easPrimaryId
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            map.put("salers",saler);
        }
        if (easPrimaryId != null && !"".equals(easPrimaryId) && !"null".equals(easPrimaryId)) {
            map.put("easPrimaryId","%" + easPrimaryId+ "%");
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleSteelReportNew(map);
        for (Map<String, Object> stringObjectMap : report) {
            String shippingAddressIds = (String) stringObjectMap.get("shippingAddressIds");
            String capacityNumbers= (String) stringObjectMap.get("capacityNumbers");
            //
            /*String priceIds = (String) stringObjectMap.get("priceIds");
            if (priceIds!=null&&!(priceIds.isEmpty())){
                String[] split = priceIds.split(",");
                int i=0;
                for (String s : split) {
                    i++;
                    if (i==1){
                        stringObjectMap.put("priceValue",statisticalReportService.getHistoryPrice(DataChange.dataToBigDecimal(s)));
                    }
                    if (i==2){
                        stringObjectMap.put("futurePriceValue",statisticalReportService.getHistoryPrice(DataChange.dataToBigDecimal(s)));
                    }
                }
            }*/
            //确认是否有多个收货单位
            if (shippingAddressIds !=null && !("".equals(shippingAddressIds))){
                String[] split = shippingAddressIds.split(",");
                String address="";
                int i=0;
                for (String s : split) {
                    i++;
                    String getaddress = statisticalReportService.getaddress(DataChange.dataToBigDecimal(s));
                    if (i==1){
                        address+="旧地址:"+getaddress+",";
                    }else if (i==2){
                        address+="新地址:"+getaddress;
                    }
                }
                stringObjectMap.put("addressPlace",address);
            }
            //确认是否有多个车牌号
            if (capacityNumbers!=null &&!("".equals(capacityNumbers))){
                String[] split = capacityNumbers.split(",");
                String capacityNumber="";
                int flag=0;
                for (String s : split) {
                    flag++;
                    String s1 = statisticalReportService.getcapacityNumber(DataChange.dataToBigDecimal(s));
                    if (flag==1){
                        capacityNumber+="旧车号:"+s1+",";
                    }else if (flag==2){
                        capacityNumber+="新车号:"+s1;
                        break;
                    }
                }
                stringObjectMap.put("capacityNo",capacityNumber);
            }
            /*try{
                BigDecimal orderId = (BigDecimal) stringObjectMap.get("orderId");
                if (orderId !=null){
                    String status = statisticalReportService.getStatus(orderId);
                    if (!(" ".equals(status))){
                        stringObjectMap.put("orderStatus",status);
                    }
                }
            }catch (Exception e){
                e.printStackTrace();
            }*/
        }
        return success(report);
    }


    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSettledSaleSteelReportNew")
    public RESTfulResult getSettledSaleSteelReportNew(@RequestBody(required=false) Map<String,Object> map,
                                               String startTime,
                                               String endTime,
                                               String carrierSsoId,
                                               String receiveName,
                                               String materialName,
                                               String specification,
                                               String remark,
                                               String capacityNo,
                                               String carrierName,
                                               String consigneeName,
                                               String saler,
                                               String easPrimaryId
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            map.put("salers",saler);
        }
        if (easPrimaryId != null && !"".equals(easPrimaryId) && !"null".equals(easPrimaryId)) {
            map.put("easPrimaryId","%" +easPrimaryId+ "%");
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSettledSaleSteelReportNew(map);
        for (Map<String, Object> stringObjectMap : report) {
            String shippingAddressIds = (String) stringObjectMap.get("shippingAddressIds");
            String capacityNumbers= (String) stringObjectMap.get("capacityNumbers");
            //确认是否有多个收货单位
            if (shippingAddressIds !=null && !("".equals(shippingAddressIds))){
                String[] split = shippingAddressIds.split(",");
                String address="";
                int i=0;
                for (String s : split) {
                    i++;
                    String getaddress = statisticalReportService.getaddress(DataChange.dataToBigDecimal(s));
                    if (i==1){
                        address+="旧地址:"+getaddress+",";
                    }else if (i==2){
                        address+="新地址:"+getaddress;
                    }
                }
                stringObjectMap.put("addressPlace",address);
            }
            //确认是否有多个车牌号
            if (capacityNumbers!=null &&!("".equals(capacityNumbers))){
                String[] split = capacityNumbers.split(",");
                String capacityNumber="";
                int flag=0;
                for (String s : split) {
                    flag++;
                    String s1 = statisticalReportService.getcapacityNumber(DataChange.dataToBigDecimal(s));
                    if (flag==1){
                        capacityNumber+="旧车号:"+s1+",";
                    }else if (flag==2){
                        capacityNumber+="新车号:"+s1;
                        break;
                    }
                }
                stringObjectMap.put("capacityNo",capacityNumber);
            }
            /*try{
                BigDecimal orderId = (BigDecimal) stringObjectMap.get("orderId");
                if (orderId !=null){
                    String status = statisticalReportService.getStatus(orderId);
                    if (!(" ".equals(status))){
                        stringObjectMap.put("orderStatus",status);
                    }
                }
            }catch (Exception e){
                e.printStackTrace();
            }*/
        }
        return success(report);
    }



    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardSaleSteelReport")
    public RESTfulResult getInwardSaleSteelReport(@RequestBody(required=false) Map<String,Object> map,
                                            String startTime,
                                            String endTime,
                                            String carrierSsoId,
                                            String receiveName,
                                            String materialName,
                                            String specification,
                                            String remark,
                                            String capacityNo,
                                            String carrierName,
                                            String consigneeName,
                                            String saler
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            map.put("salers",saler);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardSaleSteelReport(map);
        return success(report);
    }

    @ApiOperation(value="查询销售钢材派单报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getInwardSaleSteelOrder")
    public RESTfulResult getInwardSaleSteelOrder(@RequestBody(required=false) Map<String,Object> map,
                                                  String startTime,
                                                  String endTime,
                                                  String remark,
                                                  String capacityNo,
                                                  String consigneeName

    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getInwardSaleSteelOrder(map);
        return success(report);
    }

    @ApiOperation(value="根据车序号查询销售订单状态")
    @PostMapping("/getSteelReportDetailsBySmId")
    public RESTfulResult getSteelReportDetailsBySmId(@RequestParam BigDecimal saleOrderMaterialId){
        return success(statisticalReportService.getSteelReportDetailsBySmId(saleOrderMaterialId));
    }

    @ApiOperation(value = "待装钢材报表数据")
    @PostMapping("loadingSaleSteelReport")
    public RESTfulResult loadingSaleSteelReport(@RequestBody(required=false) Map<String,Object> map,
                                                String startTime,
                                                String endTime,
                                                String carrierSsoId,
                                                String receiveName,
                                                String remark,
                                                String capacityNo,
                                                String carrierName,
                                                String consigneeName,
                                                String saler,
                                                String easPrimaryId){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId) && carrierSsoId != null){
                map.put("carrierSsoId", carrierSsoId);
            }
        }
        if (receiveName != null && !"null".equals(receiveName)) {
            map.put("receivName","%" + receiveName + "%");
        }
        if (remark != null && !"".equals(remark) && !"null".equals(remark)) {
            map.put("remark","%" + remark + "%");
        }
        if (capacityNo != null && !"".equals(capacityNo) && !"null".equals(capacityNo)) {
            map.put("capacityNum","%" + capacityNo + "%");
        }
        if (carrierName != null && !"".equals(carrierName) && !"null".equals(carrierName)) {
            map.put("carrierNames","%" + carrierName + "%");
        }
        if (consigneeName != null && !"".equals(consigneeName) && !"null".equals(consigneeName)) {
            map.put("consigneeNames","%" + consigneeName + "%");
        }
        if (saler != null && !"".equals(saler) && !"null".equals(saler)) {
            map.put("salers",saler);
        }
        if (easPrimaryId != null && !"".equals(easPrimaryId) && !"null".equals(easPrimaryId)) {
            map.put("easPrimaryId",easPrimaryId);
        }
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.loadingSaleSteelReport(map);
        return success(report);
    }

    @ApiOperation(value="查询销售统计报表(财务)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleSteelReportForFinance")
    public RESTfulResult getSaleSteelReportForFinance(@RequestBody(required=false) Map<String,Object> map,
                                            String startTime,
                                            String endTime
    ){
        DataChange.queryDataByDateTimeYestDay(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSaleSteelReportForFinance(map);
        for (Map<String, Object> stringObjectMap : report) {
            String shippingAddressIds = (String) stringObjectMap.get("shippingAddressIds");
            //确认是否有多个收货单位
            if (shippingAddressIds !=null && !("".equals(shippingAddressIds))){
                String[] split = shippingAddressIds.split(",");
                String address="";
                int i=0;
                for (String s : split) {
                    i++;
                    String getaddress = statisticalReportService.getaddress(DataChange.dataToBigDecimal(s));
                    if (i==1){
                        address+="旧地址:"+getaddress+",";
                    }else if (i==2){
                        address+="新地址:"+getaddress;
                    }
                }
                stringObjectMap.put("addressPlace",address);
            }
        }
        return success(report);
    }
}
